==> lb_plus-3.1.0.tar.gz: lb_plus/src/Plugin/Tool/LbPlus.php <==
<?php

declare(strict_types=1);

namespace Drupal\lb_plus\Plugin\Tool;

use Drupal\Core\Entity\EntityInterface;
use Drupal\toolbar_plus\Attribute\Tool;
use Drupal\toolbar_plus\ToolPluginBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the tool.
 */
#[Tool(
  id: 'lb_plus',
  label: new TranslatableMarkup('Layout'),
  weight: 20,
)]
final class LbPlus extends ToolPluginBase {

  use StringTranslationTrait;

  public function __construct(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, ModuleExtensionList $extensionList, protected ModuleHandlerInterface $moduleHandler, protected AccountInterface $currentUser) {
    parent::__construct($container, $configuration, $plugin_id, $plugin_definition, $extensionList);
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static (
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('extension.list.module'),
      $container->get('module_handler'),
      $container->get('current_user'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildTopBar(): array {
    $top_bar = [];

    $top_bar['toggle_sidebar_button'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'lb-plus-toggle-sidebar',
        'title' => $this->t('Drag a block from the sidebar and place it in a drop zone on the page'),
        'class' => ['toolbar-button', 'toolbar-button--collapsible', 'toolbar-button--icon--block'],
      ],
      'label' => [
        '#type' => 'html_tag',
        '#tag' => 'span',
        '#value' => $this->t('Place a new block'),
        '#attributes' => ['class' => ['toolbar-button__label']],
      ],
    ];

    $top_bar['toggle-preview'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'toolbar-plus-toggle-preview',
        'title' => $this->t('Toggle the content placeholders'),
        'class' => ['toolbar-button', 'toolbar-button--collapsible', 'js-show'],
      ],
      'label' => [
        '#id' => 'layout-builder-content-preview',
        '#title' => $this->t('Toggle preview'),
        '#type' => 'checkbox',
        '#attributes' => [
          'data-content-preview-id' => "Drupal.layout_builder.content_preview.{$this->currentUser->id()}",
          'checked' => 'checked',
        ],
        '#label_attributes' => ['class' => ['toolbar-button__label']]
      ],
    ];

    // @todo inject
    $sidebar_state = \Drupal::request()->cookies->get('lbPlusSidebar') ?? 'closed';
    if ($sidebar_state === 'open') {
      $top_bar['toggle_sidebar_button']['#attributes']['class'][] = 'active';
    }

    return $top_bar;
  }

  /**
   * {@inheritdoc}
   */
  public function buildLeftSideBar(): array {
    return [
      // The sidebar is built in an AJAX call in LayoutBuilderPlusUi. We just
      // need the wrapper to render.
      '#type' => 'container',
      '#attributes' => [
        'id' => 'lb-plus-sidebar-placeholder',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIconsPath(): array {
    $path = $this->extensionList->getPath('lb_plus');
    return [
      'mouse_icon' => "/$path/assets/layout-builder-mouse.svg",
      'toolbar_button_icons' => [
        'lb_plus' => "/$path/assets/layout.svg",
        'block' => "/$path/assets/block.svg",
      ],
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function addAttachments(array &$attachments): void {
    $attachments['library'][] = 'lb_plus/layout_builder';
  }

  /**
   * {@inheritdoc}
   */
  public function applies(EntityInterface $entity): bool {
    $entity_type_id = $entity->getEntityTypeId();
    $bundle = $entity->bundle();
    $view_display = \Drupal::service('entity_display.repository')->getViewDisplay($entity_type_id, $bundle, 'default');

    if ($view_display) {
      // Check if Layout Builder is enabled for this view display.
      return !empty($view_display->getThirdPartySetting('layout_builder', 'enabled', FALSE));
    }
    return FALSE;
  }

}

==> lb_plus-3.1.1.tar.gz: lb_plus/src/Plugin/Tool/LbPlus.php <==
<?php

declare(strict_types=1);

namespace Drupal\lb_plus\Plugin\Tool;

use Drupal\Core\Entity\EntityInterface;
use Drupal\navigation_plus\Attribute\Tool;
use Drupal\navigation_plus\ToolPluginBase;
use Drupal\Core\Session\AccountInterface;
use Drupal\Core\Extension\ModuleExtensionList;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Plugin implementation of the tool.
 */
#[Tool(
  id: 'lb_plus',
  label: new TranslatableMarkup('Layout'),
  weight: 20,
)]
final class LbPlus extends ToolPluginBase {

  use StringTranslationTrait;

  public function __construct(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, ModuleExtensionList $extensionList, protected ModuleHandlerInterface $moduleHandler, protected AccountInterface $currentUser) {
    parent::__construct($container, $configuration, $plugin_id, $plugin_definition, $extensionList);
  }

  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static (
      $container,
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('extension.list.module'),
      $container->get('module_handler'),
      $container->get('current_user'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildTopBar(): array {
    $top_bar = [];

    $top_bar['toggle_sidebar_button'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'lb-plus-toggle-sidebar',
        'title' => $this->t('Drag a block from the sidebar and place it in a drop zone on the page'),
        'class' => ['toolbar-button', 'toolbar-button--collapsible', 'toolbar-button--icon--block'],
      ],
      'label' => [
        '#type' => 'html_tag',
        '#tag' => 'span',
        '#value' => $this->t('Place a new block'),
        '#attributes' => ['class' => ['toolbar-button__label']],
      ],
    ];

    $top_bar['toggle-preview'] = [
      '#type' => 'container',
      '#attributes' => [
        'id' => 'navigation-plus-toggle-preview',
        'title' => $this->t('Toggle the content placeholders'),
        'class' => ['toolbar-button', 'toolbar-button--collapsible', 'js-show'],
      ],
      'label' => [
        '#id' => 'layout-builder-content-preview',
        '#title' => $this->t('Toggle preview'),
        '#type' => 'checkbox',
        '#attributes' => [
          'data-content-preview-id' => "Drupal.layout_builder.content_preview.{$this->currentUser->id()}",
          'checked' => 'checked',
        ],
        '#label_attributes' => ['class' => ['toolbar-button__label']]
      ],
    ];

    // @todo inject
    $sidebar_state = \Drupal::request()->cookies->get('lbPlusSidebar') ?? 'closed';
    if ($sidebar_state === 'open') {
      $top_bar['toggle_sidebar_button']['#attributes']['class'][] = 'active';
    }

    return $top_bar;
  }

  /**
   * {@inheritdoc}
   */
  public function buildLeftSideBar(): array {
    return [
      // The sidebar is built in an AJAX call in LayoutBuilderPlusUi. We just
      // need the wrapper to render.
      '#type' => 'container',
      '#attributes' => [
        'id' => 'lb-plus-sidebar-placeholder',
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getIconsPath(): array {
    $path = $this->extensionList->getPath('lb_plus');
    return [
      'mouse_icon' => "/$path/assets/layout-builder-mouse.svg",
      'toolbar_button_icons' => [
        'lb_plus' => "/$path/assets/layout.svg",
        'block' => "/$path/assets/block.svg",
      ],
    ];

  }

  /**
   * {@inheritdoc}
   */
  public function addAttachments(array &$attachments): void {
    $attachments['library'][] = 'lb_plus/layout_builder';
  }

  /**
   * {@inheritdoc}
   */
  public function applies(EntityInterface $entity): bool {
    $entity_type_id = $entity->getEntityTypeId();
    $bundle = $entity->bundle();
    $view_display = \Drupal::service('entity_display.repository')->getViewDisplay($entity_type_id, $bundle, 'default');

    if ($view_display) {
      // Check if Layout Builder is enabled for this view display.
      return !empty($view_display->getThirdPartySetting('layout_builder', 'enabled', FALSE));
    }
    return FALSE;
  }

}
